@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
@@ -666,7 +665,7 @@ mps_fill_sheet (MpsState *state)
 
 	/* ---------------------------------------- */
 
-	{
+	if (state->rows->len > 0) {
 		int x = OBJ_BASE_COL;
 		int y = OBJ_BASE_ROW;
 		MpsRow *row = g_ptr_array_index (state->rows, 0);
