@@ -47,6 +47,8 @@
 static gboolean
 gnm_filter_op_needs_value (GnmFilterOp op)
 {
+	g_return_val_if_fail (op != GNM_FILTER_UNUSED, FALSE);
+
 	switch (op & GNM_FILTER_OP_TYPE_MASK) {
 	case GNM_FILTER_OP_TYPE_OP:
 	case GNM_FILTER_OP_TYPE_BUCKETS:
@@ -75,7 +77,8 @@ gnm_filter_condition_new_single (GnmFilterOp op, GnmValue *v)
 {
 	GnmFilterCondition *res;
 
-	g_return_val_if_fail ((v != NULL) == gnm_filter_op_needs_value (op), NULL);
+	g_return_val_if_fail ((v != NULL) == gnm_filter_op_needs_value (op),
+			      (value_release (v), NULL));
 
 	res = g_new0 (GnmFilterCondition, 1);
 	res->op[0] = op;	res->op[1] = GNM_FILTER_UNUSED;
@@ -101,8 +104,10 @@ gnm_filter_condition_new_double (GnmFilterOp op0, GnmValue *v0,
 {
 	GnmFilterCondition *res;
 
-	g_return_val_if_fail ((v0 != NULL) == gnm_filter_op_needs_value (op0), NULL);
-	g_return_val_if_fail ((v1 != NULL) == gnm_filter_op_needs_value (op1), NULL);
+	g_return_val_if_fail ((v0 != NULL) == gnm_filter_op_needs_value (op0),
+			      (value_release (v0), value_release (v1), NULL));
+	g_return_val_if_fail ((v1 != NULL) == gnm_filter_op_needs_value (op1),
+			      (value_release (v0), value_release (v1), NULL));
 
 	res = g_new0 (GnmFilterCondition, 1);
 	res->op[0] = op0;	res->op[1] = op1;
@@ -232,7 +237,7 @@ filter_expr_eval (GnmFilterOp op, GnmValue const *src, GORegexp const *regexp,
 		char *str = filter_cell_contents (cell);
 		GORegmatch rm;
 		int res = go_regexec (regexp, str, 1, &rm, 0);
-		gboolean whole = (rm.rm_so == 0 && str[rm.rm_eo] == 0);
+		gboolean whole = (res == GO_REG_OK && rm.rm_so == 0 && str[rm.rm_eo] == 0);
 
 		g_free (str);
 
@@ -505,7 +510,7 @@ gnm_filter_combo_apply (GnmFilterCombo *fcombo, Sheet *target_sheet)
 				data.count  = 0.5 + cond->count * (end_row - start_row + 1) /100.;
 				if (data.count < 1)
 					data.count = 1;
-				data.vals   = g_alloca (sizeof (GnmValue *) * data.count);
+				data.vals   = g_new (GnmValue const *, data.count);
 				sheet_foreach_cell_in_range (filter->sheet,
 							     CELL_ITER_IGNORE_HIDDEN | CELL_ITER_IGNORE_BLANK,
 							     col, start_row, col, end_row,
@@ -515,6 +520,7 @@ gnm_filter_combo_apply (GnmFilterCombo *fcombo, Sheet *target_sheet)
 							     CELL_ITER_IGNORE_HIDDEN,
 							     col, start_row, col, end_row,
 							     (CellIterFunc) cb_hide_unwanted_items, &data);
+				g_free (data.vals);
 			} else {
 				FilterPercentage data;
 				gnm_float	 offset;
@@ -539,7 +545,8 @@ gnm_filter_combo_apply (GnmFilterCombo *fcombo, Sheet *target_sheet)
 			data.find_max = (cond->op[0] & 0x1) ? FALSE : TRUE;
 			data.elements    = 0;
 			data.count  = cond->count;
-			data.vals   = g_alloca (sizeof (GnmValue *) * data.count);
+			data.vals   = g_new (GnmValue const *, data.count);
+
 			sheet_foreach_cell_in_range (filter->sheet,
 				CELL_ITER_IGNORE_HIDDEN | CELL_ITER_IGNORE_BLANK,
 				col, start_row, col, end_row,
@@ -549,6 +556,7 @@ gnm_filter_combo_apply (GnmFilterCombo *fcombo, Sheet *target_sheet)
 				CELL_ITER_IGNORE_HIDDEN,
 				col, start_row, col, end_row,
 				(CellIterFunc) cb_hide_unwanted_items, &data);
+			g_free (data.vals);
 		}
 	} else
 		g_warning ("Invalid operator %d", cond->op[0]);
@@ -635,7 +643,7 @@ gnm_filter_add_field (GnmFilter *filter, int i)
 	tmp.start.row = tmp.end.row = filter->r.start.row;
 	tmp.start.col = tmp.end.col = filter->r.start.col + i;
 	sheet_object_anchor_init (&anchor, &tmp, a_offsets,
-		GOD_ANCHOR_DIR_DOWN_RIGHT);
+		GOD_ANCHOR_DIR_DOWN_RIGHT, GNM_SO_ANCHOR_TWO_CELLS);
 	sheet_object_set_anchor (GNM_SO (fcombo), &anchor);
 	sheet_object_set_sheet (GNM_SO (fcombo), filter->sheet);
 
