@@ -13,13 +13,13 @@ $| = 1;
                            test_csv_format_guessing
 			   test_ssindex sstest test_command message subtest
                            test_tool
-			   $ssconvert $sstest $ssdiff $gnumeric
+			   $ssconvert $sstest $ssdiff $ssgrep $gnumeric
                            $topsrc $top_builddir
 			   $subtests $samples corpus $PERL);
 @GnumericTest::EXPORT_OK = qw(junkfile);
 
 use vars qw($topsrc $top_builddir $samples $default_subtests $default_corpus $PERL $verbose);
-use vars qw($ssconvert $ssindex $sstest $ssdiff $gnumeric);
+use vars qw($ssconvert $ssindex $sstest $ssdiff $ssgrep $gnumeric);
 use vars qw($normalize_gnumeric);
 
 $PERL = $Config{'perlpath'};
@@ -35,6 +35,7 @@ $ssconvert = "$top_builddir/src/ssconvert";
 $ssindex = "$top_builddir/src/ssindex";
 $sstest = "$top_builddir/src/sstest";
 $ssdiff = "$top_builddir/src/ssdiff";
+$ssgrep = "$top_builddir/src/ssgrep";
 $gnumeric = "$top_builddir/src/gnumeric";
 $normalize_gnumeric = "$PERL $topsrc/test/normalize-gnumeric";
 $verbose = 0;
@@ -454,13 +455,14 @@ sub test_importer {
 # -----------------------------------------------------------------------------
 
 sub test_exporter {
-    my ($file) = @_;
+    my ($file,$ext) = @_;
 
     &report_skip ("file $file does not exist") unless -r $file;
 
     my $tmp = fileparse ($file);
-    $tmp =~ s/\.([a-zA-Z0-9]+)$// or die "Must have extension for export test.";
-    my $ext = $1;
+    $tmp =~ s/\.([a-zA-Z0-9]+)$//;
+    $ext = $1 unless defined $ext;
+    $ext or die "Must have extension for export test.";
     my $code;
     my $keep = 0;
 
@@ -493,12 +495,12 @@ sub test_exporter {
 
     my $tmp4 = "$tmp.xml";
     &junkfile ($tmp4) unless $keep;
-    $code = system (&quotearg ("zcat", "-f", $tmp1) . " >" . &quotearg ($tmp4));
+    $code = system (&quotearg ("zcat", "-f", $tmp1) . "| $normalize_gnumeric >" . &quotearg ($tmp4));
     &system_failure ('zcat', $code) if $code;
 
     my $tmp5 = "$tmp-new.xml";
     &junkfile ($tmp5) unless $keep;
-    $code = system (&quotearg ("zcat" , "-f", $tmp3) . " >" . &quotearg ($tmp5));
+    $code = system (&quotearg ("zcat" , "-f", $tmp3) . " | $normalize_gnumeric >" . &quotearg ($tmp5));
     &system_failure ('zcat', $code) if $code;
 
     $code = system ('diff', '-u', $tmp4, $tmp5);
