@@ -40,7 +40,7 @@ if (!-r $schema) {
 if (!-r $schema_ext) {
     print STDERR "Cannot find extended conformance schema\n";
     $schema_ext = undef;
-    # This is not a schema supplies by oasis
+    # This is not a schema supplied by oasis
     $suggest_download = 1;
 }
 if (!-r $schema_manifest) {
@@ -62,7 +62,7 @@ my %checkers = ( 0 => $checker,
 my @sources = &GnumericTest::corpus();
 # xmllint hangs on these files.  (Well, amath finishes but takes too
 # long.)
-@sources = grep { !m{(^|/)(amath|crlibm|gamma)\.gnumeric$} } @sources;
+@sources = grep { !m{(^|/)(amath|crlibm|gamma|numtheory)\.gnumeric$} } @sources;
 
 my $nskipped = 0;
 my $ngood = 0;
